@@ -60,7 +60,8 @@ function (
   outfile <- star(outfile,run)
   if(!file.exists(ctlfile))stop(ctlfile,' not found')
   control <- read.nmctl(ctlfile)
-  outputdomain <- names(control) =='table' | contains('est',names(control))
+  #outputdomain <- names(control) =='table' | contains('est',names(control))
+  outputdomain <- names(control) %contains% 'tab|est'
   control[outputdomain] <- lapply(control[outputdomain],explicitPath)
   if (checkrunno) {
   	  problemdomain <- contains('prob',names(control))
@@ -208,9 +209,9 @@ function (
   		files <- dir(dir)
   		files <- grep(pattern,files,value=TRUE,ignore.case=TRUE)
   		#if(length(files))file.remove(paste(dir,files,sep='/'))
-      if(length(files)) files <- paste(dir,files,sep='/')
-      lapply(files[file_test('-f',files)],file.remove)
-      lapply(files[file_test('-d',files)],purge.dir)     
+  		if(length(files)) files <- paste(dir,files,sep='/')
+  		lapply(files[file_test('-f',files)],file.remove)
+  		lapply(files[file_test('-d',files)],purge.dir)     
   	}
   }
   episcript <- function(script,...){
